@@ -25,6 +25,7 @@ knn = {
 	'weights':['uniform','distance']
 }
 
+
 lightgbm = {
 	'max_depth':[2,3]
 }
@@ -33,12 +34,12 @@ mlp = {
 	'activation':['relu','tanh'],
 	'hidden_layer_sizes':[(25,),(25,25,)],
 	'solver':['lbfgs','adam'],
-	'normalizer':['pt','minmax'],
+	'normalizer':['minmax','scale'],
 	'random_state':[20]
 }
 
 mlr = {
-	'normalizer':['scale','minmax','pt',None]
+	'normalizer':['scale','minmax',None]
 }
 
 prophet = {
@@ -46,7 +47,7 @@ prophet = {
 }
 
 rf = {
-	'max_depth':[5,10,None],
+	'max_depth':[2,5],
 	'n_estimators':[100,500,1000]
 }
 
